# 3段法进行拼接
# 暂时使用这两张图片做测试
# img2_full = cv2.imread('pics2/230514_104354LeftEC.jpg')
# img1_full = cv2.imread('pics2/230514_104354RightEC.jpg')
# 将img2_full拆成2个部分
# 右侧贴在img1_full的左侧，左侧贴在img1_full的右侧
# 拼接方案待定

import cv2
import numpy as np

def find_keypoints_and_matches_flann(img1, img2):
    sift = cv2.SIFT_create()
    keypoints1, descriptors1 = sift.detectAndCompute(img1, None)
    keypoints2, descriptors2 = sift.detectAndCompute(img2, None)

    FLANN_INDEX_KDTREE = 1
    index_params = dict(algorithm=FLANN_INDEX_KDTREE, trees=5)
    search_params = dict(checks=50)
    flann = cv2.FlannBasedMatcher(index_params, search_params)

    matches = flann.knnMatch(descriptors1, descriptors2, k=2)

    return keypoints1, keypoints2, matches

def filter_distance(matches, ratio=0.6):
    good_matches = []
    for m, n in matches:
        if m.distance < ratio * n.distance:
            good_matches.append(m)
    return good_matches

def filter_edge_points(control_points1, control_points2, img1_full, img2_full):
    filtered_control_points1 = []
    filtered_control_points2 = []
    for pt1, pt2 in zip(control_points1, control_points2):
        if pt1[0] > img1_full.shape[1] * 0.9 and pt2[0] < img2_full.shape[1] * 0.1:
            filtered_control_points1.append(pt1)
            filtered_control_points2.append(pt2)

    return filtered_control_points1, filtered_control_points2

# 高度差距过大的点不要
def filter_height_diff(control_points1, control_points2, img1_full, img2_full):
    filtered_control_points1 = []
    filtered_control_points2 = []
    for pt1, pt2 in zip(control_points1, control_points2):
        if abs(pt1[1] - pt2[1]) < img1_full.shape[0] * 0.02:
            filtered_control_points1.append(pt1)
            filtered_control_points2.append(pt2)

    return filtered_control_points1, filtered_control_points2

def get_control_points_flann(img1_full, img2_full):
    keypoints1, keypoints2, matches = find_keypoints_and_matches_flann(img1_full, img2_full)

    # Apply filters
    matches = filter_distance(matches, ratio=0.65)

    control_points1 = []
    control_points2 = []
    for m in matches:
        pt1 = keypoints1[m.queryIdx].pt
        pt2 = keypoints2[m.trainIdx].pt

        control_points1.append(pt1)
        control_points2.append(pt2)

    # Uncomment the line below to enable the edge points filter
    control_points1, control_points2 = filter_edge_points(control_points1, control_points2, img1_full, img2_full)
    control_points1, control_points2 = filter_height_diff(control_points1, control_points2, img1_full, img2_full)

    return np.float32(control_points1), np.float32(control_points2)

def translate_image_y(img, y_offset):
    translated_img = np.zeros_like(img)
    if y_offset > 0:
        translated_img[y_offset:, :] = img[:-y_offset, :]
    elif y_offset < 0:
        translated_img[:y_offset, :] = img[-y_offset:, :]
    else:
        translated_img = img.copy()
    return translated_img

# 对步骤进行优化
def stitch2(img1,img2):
    # 将img2分成两部分
    img2_left = img2[:, :int(img2.shape[1] / 2)]
    img2_right = img2[:, int(img2.shape[1] / 2):]

    # 计算 img2_right 和 img1 的特征点
    control_points1, control_points2 = get_control_points_flann(img2_right, img1)
    overlap_width1 = img2_right.shape[1] - int(min(control_points1, key=lambda x: x[0])[0]) + int(min(control_points2, key=lambda x: x[0])[0])
    # 计算 偏移均值left
    dv1 = np.mean(control_points1 - control_points2, axis=0)

    # 计算 img1 和 img2_left 的特征点
    control_points1, control_points2 = get_control_points_flann(img1, img2_left)
    overlap_width2 = img1.shape[1] - int(min(control_points1, key=lambda x: x[0])[0]) + int(min(control_points2, key=lambda x: x[0])[0])
    # 计算 偏移均值right
    dv2 = np.mean(control_points1 - control_points2, axis=0)

    # 尝试对 偏移均值left 和 偏移均值right 进行统一，最好是个轴对称，如果不是会很麻烦，需要调整两个摄像头的物理位置
    # 由于一个是img2_right 和 img1，另一个是 img1 和 img2_left，所以他们的dv[1]是相反数
    # 对dv[1]取平均值，再按照原来的符号赋值给dv[1]
    dv1[1] = -dv1[1]
    avg_dv1 = (dv1[1] + dv2[1]) / 2
    dv1[1] = -avg_dv1
    dv2[1] = avg_dv1

    dh = int(avg_dv1)

    # 左右的接缝宽度暂时不做处理

    # 计算画布的应有尺寸
    # 应有尺寸的宽度应该是 img1.shape[1] + img2.shape[1] - overlap_width1 - overlap_width2
    # 应有尺寸的高度应该是 img1.shape[0]，这里以img1的高度为准
    # 制作一个空的画布
    stitchedResult = np.zeros((img1.shape[0], img1.shape[1] + img2.shape[1] - overlap_width1 - overlap_width2, 3), dtype=np.uint8)
    # 先放img1，他的高度是不做修正的
    # 他的位置应该是在img2_right的宽度 - overlap_width1
    stitchedResult[:, img2_right.shape[1] - overlap_width1:img2_right.shape[1] - overlap_width1 + img1.shape[1]] = img1

    # 计算并将img2_right放在左侧
    # 先将img2_right上下平移，平移量为dv1[1]*-1
    img2_right_translated = translate_image_y(img2_right, int(dv1[1]*-1))
    # 将img2_right_translated放在stitchedResult的左侧
    stitchedResult[:, :img2_right.shape[1]] = img2_right_translated[:, :img2_right.shape[1]]

    # 计算并将img2_left放在右侧
    # 先将img2_left上下平移，平移量为dv2[1]
    img2_left_translated = translate_image_y(img2_left, int(dv2[1]))
    # 将img2_left_translated放在stitchedResult的右侧
    stitchedResult[:, img2_right.shape[1] - overlap_width1 + img1.shape[1]-overlap_width2:] = img2_left_translated

    # 渐变权重，对接缝进行模糊处理，左侧接缝
    overlap_start = img2_right.shape[1] - overlap_width1
    overlap_end = img2_right.shape[1]
    # 计算重叠区域的权重矩阵
    weight_matrix = np.linspace(0, 1, overlap_end - overlap_start).reshape(1, -1, 1)
    # 使用权重矩阵对重叠区域进行加权平均
    stitchedResult[:, overlap_start:overlap_end] = weight_matrix * img1[:,:overlap_width1] + (1 - weight_matrix) * img2_right_translated[:, overlap_start:overlap_end]

    # 渐变权重，对接缝进行模糊处理，右侧接缝
    overlap_start = img2_right.shape[1] - overlap_width1 + img1.shape[1]-overlap_width2
    overlap_end = img2_right.shape[1] - overlap_width1 + img1.shape[1]
    # 计算重叠区域的权重矩阵
    weight_matrix = np.linspace(0, 1, overlap_end - overlap_start).reshape(1, -1, 1)
    # 使用权重矩阵对重叠区域进行加权平均
    stitchedResult[:, overlap_start:overlap_end] = weight_matrix * img2_left_translated[:, :overlap_width2] + (1 - weight_matrix) * img1[:, -overlap_width2:]

    # 显示结果
    # cv2.imshow('stitchedResult', stitchedResult)
    # cv2.waitKey(0)
    # cv2.destroyAllWindows()
    
    # 结果保存
    # cv2.imwrite('pics2/stitchedResult.jpg', stitchedResult)
    return overlap_width1,overlap_width2,dh

# 不再校准，直接用stitch2的结果进行拼接
# 参数：img1是正面图像，img2是背面图像，争取保证正面图像的质量，如果必要牺牲背面图像的质量
# overlap_width1和overlap_width2是两个接缝的宽度
# dh是高度差，这里强制要求两边高度差一致，就是stitch2种dv[1]的平均值
def stitch3(img1,img2,overlap_width1,overlap_width2,dh):
    # 这里面不再调整两张图片的大小，要求图片大小一致
    # TODO：转等距投影的部分把图片大小调整一致

    # 将img2分成两部分
    img2_left = img2[:, :int(img2.shape[1] / 2)]
    img2_right = img2[:, int(img2.shape[1] / 2):]

    stitchedResult = np.zeros((img1.shape[0], img1.shape[1] + img2.shape[1] - overlap_width1 - overlap_width2, 3), dtype=np.uint8)
    # 先放img1，他的高度是不做修正的
    # 他的位置应该是在img2_right的宽度 - overlap_width1
    stitchedResult[:, img2_right.shape[1] - overlap_width1:img2_right.shape[1] - overlap_width1 + img1.shape[1]] = img1

    # 计算并将img2_right放在左侧
    img2_right_translated = translate_image_y(img2_right, dh)
    # 将img2_right_translated放在stitchedResult的左侧
    stitchedResult[:, :img2_right.shape[1]] = img2_right_translated[:, :img2_right.shape[1]]

    # 计算并将img2_left放在右侧
    img2_left_translated = translate_image_y(img2_left, dh)
    # 将img2_left_translated放在stitchedResult的右侧
    stitchedResult[:, img2_right.shape[1] - overlap_width1 + img1.shape[1]-overlap_width2:] = img2_left_translated

    # 渐变权重，对接缝进行模糊处理，左侧接缝
    overlap_start = img2_right.shape[1] - overlap_width1
    overlap_end = img2_right.shape[1]
    # 计算重叠区域的权重矩阵
    weight_matrix = np.linspace(0, 1, overlap_end - overlap_start).reshape(1, -1, 1)
    # 使用权重矩阵对重叠区域进行加权平均
    stitchedResult[:, overlap_start:overlap_end] = weight_matrix * img1[:,:overlap_width1] + (1 - weight_matrix) * img2_right_translated[:, overlap_start:overlap_end]

    # 渐变权重，对接缝进行模糊处理，右侧接缝
    overlap_start = img2_right.shape[1] - overlap_width1 + img1.shape[1]-overlap_width2
    overlap_end = img2_right.shape[1] - overlap_width1 + img1.shape[1]
    # 计算重叠区域的权重矩阵
    weight_matrix = np.linspace(0, 1, overlap_end - overlap_start).reshape(1, -1, 1)
    # 使用权重矩阵对重叠区域进行加权平均
    stitchedResult[:, overlap_start:overlap_end] = weight_matrix * img2_left_translated[:, :overlap_width2] + (1 - weight_matrix) * img1[:, -overlap_width2:]

    # # 显示结果
    # cv2.imshow('stitchedResult', stitchedResult)
    # cv2.waitKey(0)
    # cv2.destroyAllWindows()
    
    # # 结果保存
    # cv2.imwrite('pics2/stitchedResult.jpg', stitchedResult)
    return stitchedResult


def main():
    img1 = cv2.imread('pics2/230514_104354LeftEC.jpg')
    img2 = cv2.imread('pics2/230514_104354RightEC.jpg')
    # 将两张图片的shape调整为一致，按照较小的那张图片的shape进行调整
    if img1.shape[0] < img2.shape[0]:
        img2 = cv2.resize(img2, (img1.shape[1], img1.shape[0]))
    else:
        img1 = cv2.resize(img1, (img2.shape[1], img2.shape[0]))

    overlap_width1,overlap_width2,dh = stitch2(img1,img2)

    img3 = cv2.imread('pics2/230514_104323LeftEC.jpg')
    img4 = cv2.imread('pics2/230514_104323RightEC.jpg')

    if img3.shape[0] < img4.shape[0]:
        img4 = cv2.resize(img4, (img3.shape[1], img3.shape[0]))
    else:
        img3 = cv2.resize(img3, (img4.shape[1], img4.shape[0]))


    stitch3(img3,img4,overlap_width1,overlap_width2,dh)

# main()


import os
import cv2 
import json

import numpy as np
from .fisheye2Equirectangular import fisheye2Equirectangular
from .stitchEasy3 import stitch2,stitch3

def calibCircleCenter(image,x,y,r):
    # 步长暂定为图像宽高的0.5%
    step = int(0.005 * max(image.shape[:2]))

    def draw_circle_center(image, circle_center):
        x, y, r = circle_center
        image_with_center = image.copy()
        cv2.circle(image_with_center, (x, y), 5, (0, 255, 0), -1)
        cv2.circle(image_with_center, (x, y), r, (0, 255, 0), 2)
        return image_with_center
    
    while True:
        # 在图像上绘制圆心和圆
        image_with_center = draw_circle_center(image, (x, y, r))

        # 显示绘制圆心和圆后的图像
        cv2.imshow('Image with Circle Center and Circle', image_with_center)

        # 获取键盘输入
        key = cv2.waitKey(0) & 0xFF

        # 根据键盘输入调整圆心和半径
        if key == ord('a'):
            x -= step
        elif key == ord('s'):
            y += step
        elif key == ord('w'):
            y -= step
        elif key == ord('d'):
            x += step
        elif key == ord('q'):
            r -= step
        elif key == ord('e'):
            r += step
        elif key == 13:  # 回车键
            break

    return int(x),int(y),int(r)

# 按照配置中的圆心和半径进行切割，将两张图片切割成两个矩形，超出原有图像的部分用黑色填充
def crop_image(image, circle_center):
    x, y, r = circle_center
    h, w, _ = image.shape
    top = max(0, y - r)
    bottom = min(h, y + r)
    left = max(0, x - r)
    right = min(w, x + r)
    cropped_image = np.zeros((2 * r, 2 * r, 3), dtype=np.uint8)
    cropped_image[top - (y - r):bottom - (y - r), left - (x - r):right - (x - r)] = image[top:bottom, left:right]
    return cropped_image

class Stitcher:
    def __init__(self) -> None:
        self.config_path = './config.json'
        self.config = self.readConfig()
    
    def readConfig(self):
        # 读取配置文件，配置文件在 './config.json' 中
        # 如果文件不存在，那么就初始化一个配置文件
        # 如果文件存在，那么就读取配置文件
        # 返回一个字典
        # 初始值 就是一个空字典
        # 目前该字典中包含的键值对有：
        # img1 = 'left',这里left指的是获得的拼接图像的左侧部分，也就是img2是右侧部分
        # img1CircleCenter = [x,y],这里的0,0指的是圆心的坐标,注意是切分成两个图像后的圆心坐标
        # img2CircleCenter = [x,y],这里的0,0指的是圆心的坐标,注意是切分成两个图像后的圆心坐标
        # imgCircleRadius = 0,这里的r指的是圆的半径，两个圆的半径要一致
        # overlap_width1 = 0,
        # overlap_width2 = 0
        # dh = 0
        config_path = self.config_path

        # 如果配置文件不存在，初始化一个空字典作为配置
        if not os.path.exists(config_path):
            config = {}
            with open(config_path, 'w') as config_file:
                json.dump(config, config_file)
        else:
            # 如果配置文件存在，读取配置文件
            with open(config_path, 'r') as config_file:
                # 尝试反序列化配置文件，如果不能有效的将配置文件反序列化，那么就警告
                # 并将配置文件初始化为空字典
                try:
                    config = json.load(config_file)
                except:
                    print('警告：配置文件格式错误，将初始化配置文件')
                    config = {}
                    with open(config_path, 'w') as config_file:
                        json.dump(config, config_file)

        return config

    def writeConfig(self):
        config_path = self.config_path
        # 将配置写入配置文件
        with open(config_path, 'w') as config_file:
            json.dump(self.config, config_file, indent=4)

    def calibMainCamera(self,mainCamera = 'left'):
        # mainCamera参数必须是'left'或者'right'，否则会报错
        if mainCamera != 'left' and mainCamera != 'right':
            raise Exception('mainCamera参数必须是left或者right')
        
        self.config['img1'] = mainCamera
        # 我的相机是210度的，所以fov是210，这里暂时写死
        self.config['fov'] = 210
        self.writeConfig()

    def calibCircleCenter(self,img):
        # img 是左右拼接的图片，每次校准要两个一起校准
        # 将图片分开
        img1 = img[:, :int(img.shape[1] / 2)]
        img2 = img[:, int(img.shape[1] / 2):]

        # 如果配置文件中有圆心和半径的配置，那么就读取配置
        # 否则要自动探测，这个不太准，聊胜于无
        if 'img1CircleCenter' in self.config and 'img2CircleCenter' in self.config and 'imgCircleRadius' in self.config:
            x1,y1 = self.config['img1CircleCenter']
            x2,y2 = self.config['img2CircleCenter']
            r1 = r2 = self.config['imgCircleRadius']
        else:
            def detect_circle_center(image): 
                gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY) 
                blur = cv2.GaussianBlur(gray, (5, 5), 0) 
                circles = cv2.HoughCircles(blur, cv2.HOUGH_GRADIENT, 1, 20, param1=50, param2=30, minRadius=0, maxRadius=0) 
                if circles is not None: 
                    circles = np.round(circles[0, :]).astype("int") 
                    x, y, r = circles[0] 
                    return x, y, r 
                return None
            x1,y1,r1 = detect_circle_center(img1)
            x2,y2,r2 = detect_circle_center(img2)

        x1,y1,r1 = calibCircleCenter(img1,x1,y1,r1)
        x2,y2,r2 = calibCircleCenter(img2,x2,y2,r2)

        r = int((r1+r2)/2)
        # 写配置
        self.config['img1CircleCenter'] = [x1,y1]
        self.config['img2CircleCenter'] = [x2,y2]
        self.config['imgCircleRadius'] = r
        self.writeConfig()

    def calibStitch(self,img):
        # 进行判断，
        # 如果配置文件中没有img1，则默认左侧是img1
        # 如果配置文件中没有圆心和半径的配置，那么就报错，调用者收到这个报错应该调用calibCircleCenter
        if 'img1' not in self.config:
            self.calibMainCamera()
        if 'img1CircleCenter' not in self.config or 'img2CircleCenter' not in self.config or 'imgCircleRadius' not in self.config:
            raise Exception('请先校准圆心和半径，调用calibCircleCenter')
        
        # 将图片分开
        img1 = img[:, :int(img.shape[1] / 2)]
        img2 = img[:, int(img.shape[1] / 2):]
        
        img1Croped = crop_image(img1,(self.config['img1CircleCenter'][0],self.config['img1CircleCenter'][1],self.config['imgCircleRadius']))
        img2Croped = crop_image(img2,(self.config['img2CircleCenter'][0],self.config['img2CircleCenter'][1],self.config['imgCircleRadius']))


        # 将两张方图分别做成等距投影
        img1EC = fisheye2Equirectangular(img1Croped, self.config['fov'])
        img2EC = fisheye2Equirectangular(img2Croped, self.config['fov'])

        overlap_width1,overlap_width2,dh = stitch2(img1EC,img2EC)
        # 写配置文件
        self.config['overlap_width1'] = overlap_width1
        self.config['overlap_width2'] = overlap_width2
        self.config['dh'] = dh
        self.writeConfig()

    def stitch(self,img):
        # 进行判断，
        # 如果配置文件中没有img1，则默认左侧是img1
        # 如果配置文件中没有圆心和半径的配置，那么就报错，调用者收到这个报错应该调用calibCircleCenter
        if 'img1' not in self.config:
            self.calibMainCamera()
        if 'img1CircleCenter' not in self.config or 'img2CircleCenter' not in self.config or 'imgCircleRadius' not in self.config:
            raise Exception('请先校准圆心和半径，调用calibCircleCenter')
        # 如果配置文件中没有overlap_width1，overlap_width2，dh的配置，那么就报错，调用者收到这个报错应该调用calibStitch
        if 'overlap_width1' not in self.config or 'overlap_width2' not in self.config or 'dh' not in self.config:
            raise Exception('请先校准拼接，调用calibStitch')
        # 将图片分开
        img1 = img[:, :int(img.shape[1] / 2)]
        img2 = img[:, int(img.shape[1] / 2):]

        img1Croped = crop_image(img1,(self.config['img1CircleCenter'][0],self.config['img1CircleCenter'][1],self.config['imgCircleRadius']))
        img2Croped = crop_image(img2,(self.config['img2CircleCenter'][0],self.config['img2CircleCenter'][1],self.config['imgCircleRadius']))


        # 将两张方图分别做成等距投影
        img1EC = fisheye2Equirectangular(img1Croped, self.config['fov'])
        img2EC = fisheye2Equirectangular(img2Croped, self.config['fov'])

        stitchedResult = stitch3(img1EC,img2EC,self.config['overlap_width1'],self.config['overlap_width2'],self.config['dh'])

        return stitchedResult



    

if __name__ == '__main__':
    pano = Stitcher()
    # pano.calibMainCamera('left')
    # pano.calibCircleCenter(cv2.imread('pics2/230514_104323.jpg'))
    # print(pano.config)
    # pano.calibStitch(cv2.imread('pics2/230514_104354.jpg'))
    img = pano.stitch(cv2.imread('../pics/230514_104354.jpg'))
    print(img.shape)
    cv2.imshow('img',img)
    cv2.waitKey(0)
    cv2.destroyAllWindows()



from setuptools import setup, find_packages

setup(
    name="your-library-name",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        'numpy',
        'opencv-python',
    ],
    author="u03013112",
    author_email="u03013112@hotmail.com",
    description="stitcher for two fisheye camera",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/u03013112/pano",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)



# 圆形鱼眼图片
# 输入是图片，readFishEyePic返回值，一个正方的图片，与圆形外切，超出画面的部分用黑色填充。
# 用opencv的buildMap和remap方式，把圆形鱼眼图片转换成等距投影图。
# 可输入参数：鱼眼视角（上下左右都是这个角度）
# 不在输入参数：鱼眼图片宽高，这个由输入图片决定
# 不在输入参数：输出图片宽高，这个由输入图片和鱼眼视角参数决定
# 将转换完的图片展示在窗口中，按回车退出
# 返回值：转换完的图片

import cv2
import numpy as np

def equirect_proj(x_proj, y_proj, W, H, fov):
    theta_alt = x_proj * fov / W
    phi_alt = y_proj * np.pi / H

    x = np.sin(theta_alt) * np.cos(phi_alt)
    y = np.sin(phi_alt)
    z = np.cos(theta_alt) * np.cos(phi_alt)

    return np.arctan2(y, x), np.arctan2(np.sqrt(x**2 + y**2), z)

def buildmap(Ws, Hs, Wd, Hd, fov=180.0):
    fov = fov * np.pi / 180.0

    ys, xs = np.indices((Hs, Ws), np.float32)
    y_proj = Hs / 2.0 - ys
    x_proj = xs - Ws / 2.0

    theta, phi = equirect_proj(x_proj, y_proj, Ws, Hs, fov)

    p = Hd * phi / fov

    y_fish = p * np.sin(theta)
    x_fish = p * np.cos(theta)

    ymap = Hd / 2.0 - y_fish
    xmap = Wd / 2.0 + x_fish
    return xmap, ymap

# 修改fisheye2Equirectangular，添加参数needShow，默认是False
# 如果needShow是False，就不再显示图片
def fisheye2Equirectangular(fisheye_image, fov_degrees, needShow=False):
    src_height, src_width, _ = fisheye_image.shape
    dst_width = src_width
    dst_height = src_height

    map_x, map_y = buildmap(src_width, src_height, dst_width, dst_height, fov_degrees)
    equirectangular_image = cv2.remap(fisheye_image, map_x, map_y, cv2.INTER_LINEAR)

    if needShow:
        cv2.imshow('Equirectangular Image', equirectangular_image)
        cv2.waitKey(0)
        cv2.destroyAllWindows()

    return equirectangular_image

import os
import sys
if __name__ == '__main__':
    if len(sys.argv) < 2:
        print("错误：请输入图片文件名")
        print("用法：python readFishEyePic.py 图片文件名")
        sys.exit(1)

    img_filename = sys.argv[1]
    base_path, file_name = os.path.split(img_filename)
    file_name_without_ext = os.path.splitext(file_name)[0]
    file_name_ext = os.path.splitext(file_name)[1]
    leftFilePath = os.path.join(base_path, file_name_without_ext + 'Left' + file_name_ext)
    leftOutFilePath = os.path.join(base_path, file_name_without_ext + 'LeftEC' + file_name_ext)
    rightFilePath = os.path.join(base_path, file_name_without_ext + 'Right' + file_name_ext)
    rightOutFilePath = os.path.join(base_path, file_name_without_ext + 'RightEC' + file_name_ext)

    fisheye_image = image = cv2.imread(leftFilePath)
    fov_degrees = 210
    equirectangular_image = fisheye2Equirectangular(fisheye_image, fov_degrees)
    cv2.imwrite(leftOutFilePath,equirectangular_image)

    fisheye_image = image = cv2.imread(rightFilePath)
    fov_degrees = 210
    equirectangular_image = fisheye2Equirectangular(fisheye_image, fov_degrees)
    cv2.imwrite(rightOutFilePath,equirectangular_image)
